import { OnInit, AfterViewInit, EventEmitter } from '@angular/core';
import { AngularMaterialSchedulerService } from './angular-material-scheduler.service';
import { CalendarShift } from './models/shift.model';
import { IAMSDayClicked, IAMSDayEventClicked } from './models/month-events.interface';
import { IAMSWeekViewEventClicked, IAMSWeekViewEventRemove } from './models/week-events.interface';
import { BehaviorSubject } from 'rxjs';
export declare class AngularMaterialSchedulerComponent implements OnInit, AfterViewInit {
    private ams;
    /**
     * Defines the kind of view the library is going to show. By default month view.
     */
    view: 'year' | 'month' | 'week' | 'day';
    /**
     * Defines the locales the currentDate will use. By default the library uses en-us.
     * For additional information about the posible locales, please visit: https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Intl#Locale_identification_and_negotiation
     */
    locale: string;
    /**
     * Defines if the views have to start at sunday or monday. By default, true
     */
    startsOnSunday: boolean;
    /**
     * Defines the array of "Events" the calendar will show.
     */
    shifts: Array<CalendarShift>;
    /**
     * Defines the date that the calendar will use. If no argument is passed through the input. It will uses Date();
     */
    date: Date;
    /**
     * Defines if the view has to hide the day labels (numbers below the week days).
     * By default false.
     */
    hideWeekViewDayLabel: boolean;
    /**
     * Defines if the view has to scroll to specific hour when it fires onInit event.
     * The input receives the specific hour as an argument.
     */
    scrollWeekViewToSpecificHourOnInit: number;
    /**
     * Defines if the view has to scroll to the first event when it fires onInit event.
     */
    scrollWeekViewToFirstEventOnInit: boolean;
    /**
     * Defines if the view has to scroll to the changed event
     */
    scrollWeekViewToEventOnChange: boolean;
    /**
     * Dispatches the dayclick event from the different views across the library.
     */
    DayClicked: EventEmitter<IAMSDayClicked>;
    /**
     * Defines the event called on a specific shift.
     */
    DayEventClicked: EventEmitter<IAMSDayEventClicked>;
    /**
     * Defines the event called on a specific shift.
     */
    WeekEventClicked: EventEmitter<IAMSWeekViewEventClicked>;
    /**
     * Defines the event called on a specific shift's remove button.
     */
    WeekEventRemove: EventEmitter<IAMSWeekViewEventRemove>;
    /**
     * Defines where the shifts will live.
     */
    _shiftsStore: BehaviorSubject<CalendarShift[]>;
    _currentDate: Date;
    constructor(ams: AngularMaterialSchedulerService);
    ngOnInit(): void;
    ngOnChanges(c: any): void;
    ngAfterViewInit(): void;
    getCurrentMontName(): string;
}
