import { OnInit, OnChanges, EventEmitter } from '@angular/core';
import { AngularMaterialSchedulerService } from '../../angular-material-scheduler.service';
import { CalendarShift } from '../../models/shift.model';
import { IAMSDayClicked, IAMSDayEventClicked } from '../../models/month-events.interface';
export declare class MonthViewComponent implements OnInit, OnChanges {
    ams: AngularMaterialSchedulerService;
    /**
     * Defines the date that the view is going to use. If no argument is passed it will uses new Date()
     */
    date: Date;
    /**
     * Defines if the view will start on Sunday or on Monday. By default true.
     */
    startOnSunday: boolean;
    /**
     * Defines the locale for the view. By default en-us.
     * For more detailed information about the locales, please visit: https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Intl#Locale_identification_and_negotiation
     */
    locale: string;
    /**
     * Defines the array of events.
     */
    shifts: Array<CalendarShift>;
    /**
     * Defines the event called on day click.
     */
    DayClicked: EventEmitter<IAMSDayClicked>;
    /**
     * Defines the event called on a specific shift.
     */
    DayEventClicked: EventEmitter<IAMSDayEventClicked>;
    /**
     * Defines the array of labels we wanna iterate.
     */
    weekDaysLabel: Array<string>;
    /**
     * Defines the structure to print on the view.
     */
    monthStruct: Array<Array<Date>>;
    constructor(ams: AngularMaterialSchedulerService);
    ngOnInit(): void;
    ngOnChanges(changes: any): void;
    /**
     * Dispatches the dayclick event from the month view.
     * @param date
     * @param shifts
     */
    DayClickedOnView(date: Date, shifts: Array<CalendarShift>): void;
    /**
     * Dispatches the DayEventClick event from the month view.
     * @param date
     * @param shift
     */
    DayEventClickedOnView(event: MouseEvent, date: Date, shift: CalendarShift): void;
    /**
     * Build and returns the month structure. It will be used on the view.
     */
    private calculateMonthStruct;
}
