import { OnInit, OnChanges, EventEmitter, AfterViewInit, ElementRef, OnDestroy } from '@angular/core';
import { CalendarShift } from '../../models/shift.model';
import { AngularMaterialSchedulerService } from '../../angular-material-scheduler.service';
import { WeekViewShift } from '../../models/week-view-shift.interface';
import { IAMSWeekViewEventClicked, IAMSWeekViewEventRemove } from '../../models/week-events.interface';
export declare class WeekViewComponent implements OnInit, OnChanges, AfterViewInit, OnDestroy {
    ams: AngularMaterialSchedulerService;
    /**
     * Defines the date that the view is going to use. If no argument is passed it will uses new Date()
     */
    date: Date;
    /**
     * Defines if the view will start on Sunday or on Monday. By default true.
     */
    startOnSunday: boolean;
    /**
     * Defines the locale for the view. By default en-us.
     * For more detailed information about the locales, please visit: https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Intl#Locale_identification_and_negotiation
     */
    locale: string;
    /**
     * Defines the array of events.
     */
    shifts: Array<CalendarShift>;
    /**
     * Defines if the view has to hide the day labels (numbers below the week days).
     * By default false.
     */
    hideWeekViewDayLabel: boolean;
    /**
     * Defines if the view has to scroll to specific hour when it fires onInit event.
     * The input receives the specific hour as an argument.
     */
    scrollWeekViewToSpecificHourOnInit: number;
    /**
     * Defines if the view has to scroll to the first event when it fires onInit event.
     */
    scrollWeekViewToFirstEventOnInit: boolean;
    /**
     * Defines if the view has to scroll to the changed event
     */
    scrollWeekViewToEventOnChange: boolean;
    /**
     * Defines the event called on a specific shift.
     */
    WeekEventClicked: EventEmitter<IAMSWeekViewEventClicked>;
    /**
     * Defines the event called on a specific shift's remove button.
     */
    WeekEventRemove: EventEmitter<IAMSWeekViewEventRemove>;
    /**
     * Locates the timeline scroll container on the view.
     */
    timelineScroller: ElementRef;
    /**
     * Defines the array of labels we wanna iterate.
     */
    weekDaysLabel: Array<string>;
    /**
     * Defines the structure to print on the view.
     */
    weekStruct: Array<Date>;
    /**
     * Defines the default offset for the scrollbar in order to align the items on the view.
     */
    scrollBarOffset: number;
    /**
     * Defines the timeline.
     */
    timeline: Array<{
        date: Date;
        hourStr: string;
        idx: number;
    }>;
    /**
     * Defines where the shifts will live.
     */
    private _shiftsStore;
    /**
     * It stores the subscription for shift changes. It has to be destroyend on ngDestroy cycle.
     */
    private _subscription;
    constructor(ams: AngularMaterialSchedulerService);
    ngOnInit(): void;
    ngAfterViewInit(): void;
    ngOnChanges(changes: any): void;
    ngOnDestroy(): void;
    /**
     * Finds the shifts for specific range of hours and prepare them for rendering into the view
     */
    calculateShiftForSpecificDay(day: Date, timelineIdx: number, cell: Element): Array<WeekViewShift>;
    /**
     * Used to identify the elements on the *ngFor.
     */
    identy(index: number, item: CalendarShift): number;
    /**
     * Fires the shift clicked event to the parent.
     */
    ShiftClicked(date: Date, shift: CalendarShift): void;
    /**
     * Fires the shift removed event to the parent.
     */
    ShiftRemove(shift: CalendarShift): void;
    /**
     * Build and returns the week structured. It will be used on the view.
     */
    private calculateWeekStructure;
    /**
     * Handle if the view has to scroll to the first event on view has init.
     */
    private handleScrollToFirstEventOnInit;
    private handleScrollToSpecificHour;
}
export declare const TIME_OFFSET_BETWEEN_HOURS_IN_TIMELINE = 0.5;
export declare const TIMELINE_OFFSET_TOP_SPACE_BETWEEN_HOURS = 100;
